@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.0400';
+our $VERSION = '0.0402';
 
 use Moo;
 use strictures 2;
@@ -54,7 +54,7 @@ has outfile => (
 
 
 has type => (
-    is      => 'rw',
+    is      => 'ro',
     default => sub { 'png' },
 );
 
@@ -86,14 +86,22 @@ has verbose => (
 sub BUILD {
     my ( $self, $args ) = @_;
 
+    die 'Chord length and string length differ'
+        if $args->{chord} && length($args->{chord}) != $self->{strings};
+
     my @scale = qw/C Db D Eb E F Gb G Ab A Bb B/;
+
+    # Make a scale position index corresponding with the given tuning
     my @index = map { my $t = $_; first_index { $t eq $_ } @scale } @{ $self->tuning };
+
     my %notes;
 
     my $n = 0;
 
     for my $i ( @index ) {
         $n++;
+
+        # Make a scale note list for each string
         $notes{$n} = [ map { $scale[ ($i + $_) % @scale ] } 0 .. @scale - 1 ];
     }
 
@@ -110,6 +118,7 @@ sub draw {
     my $SPACE = $self->size;
 
     my @chord;
+    my $font;
 
     # Setup a new image
     my $i = Imager->new(
@@ -117,8 +126,13 @@ sub draw {
         ysize => $SPACE + $self->frets * $SPACE - $self->frets,
     );
     $i->box( filled => 1, color => $WHITE );
-    warn 'WARNING: Font ', $self->font, " not found\n" unless -e $self->font;
-    my $font = Imager::Font->new( file => $self->font );
+
+    if ( -e $self->font ) {
+        $font = Imager::Font->new( file => $self->font );
+    }
+    else {
+        warn 'WARNING: Font ', $self->font, " not found\n";
+    }
 
     # Draw the vertical string lines
     for my $string (0 .. $self->strings - 1) {
@@ -179,6 +193,7 @@ sub draw {
         elsif ( $note =~ /[oO0]/ ) {
             my $temp = $self->fretboard->{$string}[0];
             push @chord, $temp;
+
             print "O at 0,$string = $temp\n" if $self->verbose;
 
             $i->string(
@@ -194,6 +209,7 @@ sub draw {
         else {
             my $temp = $self->fretboard->{$string}[ ($self->position + $note - 1) % @{ $self->fretboard->{1} } ];
             push @chord, $temp;
+
             print "Dot at $note,$string = $temp\n" if $self->verbose;
 
             $i->circle(
@@ -244,7 +260,7 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.0400
+version 0.0402
 
 =head1 SYNOPSIS
 
@@ -289,9 +305,9 @@ neck position and chord name annotations for guitar, ukulele, banjo, etc.
   $dia->chord('xx0232');
   $chord = $dia->chord;
 
-A chord given in string format, where non-zero digits represent frets, C<x> (or
-C<X>) indicates a muted string and C<0> (or C<o> or C<O>) indicates an open
-string.  The default order of the strings is C<654321> from lowest to highest.
+A chord given as a string, where non-zero digits represent frets, C<x> (or C<X>)
+indicates a muted string and C<0> (or C<o> or C<O>) indicates an open string.
+The default order of the strings is C<654321> from lowest to highest.
 
 Examples:
 
